/**
 * \file LRU_queue.cc
 * \author Scott F. H. Kaplan <sfkaplan@cs.amherst.edu> and Yannis
 *         Smaragdakis <yannis@cc.gatech.edu>
 * \date January 2003
 * \brief The code for the LRU_queue class.
 *
 * This file contains the code that defines LRU_queue object methods.
 * And LRU_queue object is caqpable of keeping pages in LRU order
 * based on a sequence of references.
 **/



// ===================================================================
// INCLUDES

#include <algo.h>
#include "LRU_queue.hh"
// ===================================================================



// ===================================================================
page_s
LRU_queue::touch (const page_s* const page) {

  // Lookup the page in the queue position map.
  queue_position_map_t::iterator i = queue_position_map.find(*page);

  // Was the page found?
  if (i == queue_position_map.end()) {

    // No, so process the miss and return, as the result, the page
    // that was chosen for eviction (if any).
    return handle_miss(page);

  } else {

    // Yes, so process the hit and return that no page was evicted.
    handle_hit(page, (*i).second);
    return no_evict;

  }
} // LRU_queue::touch
// ===================================================================
